@@ -4,6 +4,7 @@
 
 //! Legacy Japanese encodings based on JIS X 0208 and JIS X 0212.
 
+use std::borrow::IntoCow;
 use util::StrCharIndex;
 use index_japanese as index;
 use types::*;
@@ -24,7 +25,7 @@ use self::ISO2022JPState::{ASCII,Katakana,Lead};
  * the upper half of JIS X 0212 in G2 (`8E [A1-DF]`), and
  * JIS X 0212 in G3 (`8F [A1-FE] [A1-FE]`).
  */
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct EUCJPEncoding;
 
 impl Encoding for EUCJPEncoding {
@@ -35,7 +36,7 @@ impl Encoding for EUCJPEncoding {
 }
 
 /// An encoder for EUC-JP with unused G3 character set.
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct EUCJPEncoder;
 
 impl EUCJPEncoder {
@@ -83,7 +84,7 @@ impl RawEncoder for EUCJPEncoder {
 
 ascii_compatible_stateful_decoder! {
     #[doc="A decoder for EUC-JP with JIS X 0212 in G3."]
-    #[deriving(Clone, Copy)]
+    #[derive(Clone, Copy)]
     struct EUCJP0212Decoder;
 
     module eucjp;
@@ -416,7 +417,7 @@ mod eucjp_tests {
  * It requires some cares to handle
  * since the second byte of JIS X 0208 can have its MSB unset.
  */
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct Windows31JEncoding;
 
 impl Encoding for Windows31JEncoding {
@@ -427,7 +428,7 @@ impl Encoding for Windows31JEncoding {
 }
 
 /// An encoder for Shift_JIS with IBM/NEC extensions.
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct Windows31JEncoder;
 
 impl Windows31JEncoder {
@@ -475,7 +476,7 @@ impl RawEncoder for Windows31JEncoder {
 
 ascii_compatible_stateful_decoder! {
     #[doc="A decoder for Shift_JIS with IBM/NEC extensions."]
-    #[deriving(Clone, Copy)]
+    #[derive(Clone, Copy)]
     struct Windows31JDecoder;
 
     module windows31j;
@@ -710,7 +711,7 @@ mod windows31j_tests {
  *   but willfully violated)
  * - JIS X 0212-1990 (`ESC $ ( D`, XXX asymmetric support)
  */
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct ISO2022JPEncoding;
 
 impl Encoding for ISO2022JPEncoding {
@@ -720,7 +721,7 @@ impl Encoding for ISO2022JPEncoding {
     fn raw_decoder(&self) -> Box<RawDecoder> { ISO2022JPDecoder::new() }
 }
 
-#[deriving(PartialEq,Clone,Copy)]
+#[derive(PartialEq,Clone,Copy)]
 enum ISO2022JPState {
     ASCII, // U+0000..007F, U+00A5, U+203E
     Katakana, // JIS X 0201: U+FF61..FF9F
@@ -728,7 +729,7 @@ enum ISO2022JPState {
 }
 
 /// An encoder for ISO-2022-JP without JIS X 0212/0213 support.
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct ISO2022JPEncoder {
     st: ISO2022JPState
 }
@@ -793,7 +794,7 @@ impl RawEncoder for ISO2022JPEncoder {
 
 stateful_decoder! {
     #[doc="A decoder for ISO-2022-JP with JIS X 0212 support."]
-    #[deriving(Clone, Copy)]
+    #[derive(Clone, Copy)]
     struct ISO2022JPDecoder;
 
     module iso2022jp;
