@@ -1,9 +1,10 @@
 // This is a part of rust-encoding.
-// Copyright (c) 2013-2014, Kang Seonghoon.
+// Copyright (c) 2013-2015, Kang Seonghoon.
 // See README.md and LICENSE.txt for details.
 
 //! Legacy simplified Chinese encodings based on GB 2312 and GB 18030.
 
+use std::borrow::IntoCow;
 use util::StrCharIndex;
 use index_simpchinese as index;
 use types::*;
@@ -31,7 +32,7 @@ use types::*;
  * - Finally, GB 18030 added four-byte sequences to GBK for becoming a pan-Unicode encoding,
  *   while adding new characters to the (former) GBK region again.
  */
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct GB18030Encoding;
 
 impl Encoding for GB18030Encoding {
@@ -42,7 +43,7 @@ impl Encoding for GB18030Encoding {
 }
 
 /// An encoder for GB 18030.
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct GB18030Encoder;
 
 impl GB18030Encoder {
@@ -90,7 +91,7 @@ impl RawEncoder for GB18030Encoder {
 
 ascii_compatible_stateful_decoder! {
     #[doc="A decoder for GB 18030."]
-    #[deriving(Clone, Copy)]
+    #[derive(Clone, Copy)]
     struct GB18030Decoder;
 
     module gb18030;
@@ -329,7 +330,7 @@ mod gb18030_tests {
  * they are equivalent to ISO-2022-CN escape sequences `ESC $ ) A` and `ESC ( B`.
  * Additional escape sequences `~~` (for a literal `~`) and `~\n` (ignored) are also supported.
  */
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct HZEncoding;
 
 impl Encoding for HZEncoding {
@@ -340,7 +341,7 @@ impl Encoding for HZEncoding {
 }
 
 /// An encoder for HZ.
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct HZEncoder {
     escaped: bool,
 }
@@ -404,7 +405,7 @@ impl RawEncoder for HZEncoder {
 
 stateful_decoder! {
     #[doc="A decoder for HZ."]
-    #[deriving(Clone, Copy)]
+    #[derive(Clone, Copy)]
     struct HZDecoder;
 
     module hz;
